# Pyoxynet package

This README has been intentionally created for Pypi. Please find a more extended and detailed description of the project on the [GitHub repository](https://github.com/andreazignoli/pyoxynet). 

## Documentation

Please refer to the extended [documentation](https://pyoxynet.readthedocs.io/en/latest/) to read the docs. 

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pyoxynet.

```bash
pip install pyoxynet
```

## Test settings

```python
import pyoxynet

# Load the TFL model
tfl_model = load_tf_model()

# Make inference on a random input
test_tfl_model(tfl_model)

```

Data required for the inference include oxygen uptake (VO2), exhaled CO2 (VCO2), minute ventilation (VE), end tidal O2 (PetO2) and CO2(PetCO2), and ventilatory equivalents (VEVO2 and VEVCO2):

| VO2 | VCO2 | VE | PetO2 | PetCO2 | VEVO2 | VEVCO2 |
|-----|------|----|-------|--------|-------|--------|
|     |      |    |       |        |       |        |
|     |      |    |       |        |       |        |
|     |      |    |       |        |       |        |

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

Please refer to the LICENSE file at the [GitHub repository](https://github.com/andreazignoli/pyoxynet). 